module AMS::System
  class << self

    # Determine whether operating system is windows.
    # @return [Boolean]
    # @since 2.0.0
    def is_windows?
      RUBY_PLATFORM =~ /mswin|mingw/i ? true : false
    end

    # Determine whether operating system is macintosh.
    # @return [Boolean]
    # @since 2.0.0
    def is_mac?
      RUBY_PLATFORM =~ /darwin/i ? true : false
    end

    # Determine whether operating system is linux.
    # @return [Boolean]
    # @since 2.0.0
    def is_linux?
      RUBY_PLATFORM =~ /linux/i ? true : false
    end

    # Get windows version.
    # @return [Numeric]
    # @see http://msdn.microsoft.com/en-us/library/windows/desktop/ms724832(v=vs.85).aspx Operating System Version
    # @since 2.0.0
    def get_windows_version
      AMS::C.get_windows_version()
    end

    # Get system metrics.
    # @param [Fixnum] index
    # @return [Fixnum]
    # @see http://msdn.microsoft.com/en-us/library/windows/desktop/ms724385%28v=vs.85%29.aspx GetSystemMetrics
    # @since 2.1.0
    def get_metrics(index)
      AMS::C.get_system_metrics(index.to_i)
    end

  end # class << self
end # module AMS::System
